==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/EventParameterReferenceSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.component.PropertyParameterSet;
import io.ciera.tool.sql.ooaofooa.component.impl.PropertyParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineEventDataItemSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateMachineEventDataItemSetImpl;
import io.ciera.tool.sql.ooaofooa.value.EventDatumValueSet;
import io.ciera.tool.sql.ooaofooa.value.EventParameterReference;
import io.ciera.tool.sql.ooaofooa.value.EventParameterReferenceSet;
import io.ciera.tool.sql.ooaofooa.value.impl.EventDatumValueSetImpl;

import java.util.Arrays;
import java.util.List;


public class EventParameterReferenceSetImpl extends InstanceSet<EventParameterReferenceSet,EventParameterReference> implements EventParameterReferenceSet {

    // attributes
    @Override
    public void setPP_Id( UniqueId ref_PP_Id ) throws XtumlException {
        for ( EventParameterReference eventparameterreference : this ) eventparameterreference.setPP_Id( ref_PP_Id );
    }
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( EventParameterReference eventparameterreference : this ) eventparameterreference.setValue_ID( ref_Value_ID );
    }
    @Override
    public void setSMedi_ID( UniqueId ref_SMedi_ID ) throws XtumlException {
        for ( EventParameterReference eventparameterreference : this ) eventparameterreference.setSMedi_ID( ref_SMedi_ID );
    }
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( EventParameterReference eventparameterreference : this ) eventparameterreference.setSM_ID( ref_SM_ID );
    }


    // selections
    @Override
    public EventDatumValueSet R834_EventDatumValue() throws XtumlException {
        EventDatumValueSet eventdatumvalueset = new EventDatumValueSetImpl();
        for ( EventParameterReference eventparameterreference : this ) eventdatumvalueset.add( eventparameterreference.R834_EventDatumValue() );
        return eventdatumvalueset;
    }
    @Override
    public StateMachineEventDataItemSet R846_StateMachineEventDataItem() throws XtumlException {
        StateMachineEventDataItemSet statemachineeventdataitemset = new StateMachineEventDataItemSetImpl();
        for ( EventParameterReference eventparameterreference : this ) statemachineeventdataitemset.add( eventparameterreference.R846_StateMachineEventDataItem() );
        return statemachineeventdataitemset;
    }
    @Override
    public PropertyParameterSet R847_PropertyParameter() throws XtumlException {
        PropertyParameterSet propertyparameterset = new PropertyParameterSetImpl();
        for ( EventParameterReference eventparameterreference : this ) propertyparameterset.add( eventparameterreference.R847_PropertyParameter() );
        return propertyparameterset;
    }


    @Override
    public EventParameterReference nullElement() {
        return EventParameterReferenceImpl.EMPTY_EVENTPARAMETERREFERENCE;
    }

    @Override
    public EventParameterReferenceSet emptySet() {
      return new EventParameterReferenceSetImpl();
    }

    @Override
    public EventParameterReferenceSet value() {
        return this;
    }

    @Override
    public List<EventParameterReference> elements() {
        return Arrays.asList(toArray(new EventParameterReference[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/EventParameterReferenceSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.component.PropertyParameterSet;
import io.ciera.tool.sql.ooaofooa.component.impl.PropertyParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineEventDataItemSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateMachineEventDataItemSetImpl;
import io.ciera.tool.sql.ooaofooa.value.EventDatumValueSet;
import io.ciera.tool.sql.ooaofooa.value.EventParameterReference;
import io.ciera.tool.sql.ooaofooa.value.EventParameterReferenceSet;
import io.ciera.tool.sql.ooaofooa.value.impl.EventDatumValueSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class EventParameterReferenceSetImpl extends InstanceSet<EventParameterReferenceSet,EventParameterReference> implements EventParameterReferenceSet {

    public EventParameterReferenceSetImpl() {
    }

    public EventParameterReferenceSetImpl(Comparator<? super EventParameterReference> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setSMedi_ID( UniqueId ref_SMedi_ID ) throws XtumlException {
        for ( EventParameterReference eventparameterreference : this ) eventparameterreference.setSMedi_ID( ref_SMedi_ID );
    }
    @Override
    public void setPP_Id( UniqueId ref_PP_Id ) throws XtumlException {
        for ( EventParameterReference eventparameterreference : this ) eventparameterreference.setPP_Id( ref_PP_Id );
    }
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( EventParameterReference eventparameterreference : this ) eventparameterreference.setSM_ID( ref_SM_ID );
    }
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( EventParameterReference eventparameterreference : this ) eventparameterreference.setValue_ID( ref_Value_ID );
    }


    // selections
    @Override
    public EventDatumValueSet R834_EventDatumValue() throws XtumlException {
        EventDatumValueSet eventdatumvalueset = new EventDatumValueSetImpl();
        for ( EventParameterReference eventparameterreference : this ) eventdatumvalueset.add( eventparameterreference.R834_EventDatumValue() );
        return eventdatumvalueset;
    }
    @Override
    public StateMachineEventDataItemSet R846_StateMachineEventDataItem() throws XtumlException {
        StateMachineEventDataItemSet statemachineeventdataitemset = new StateMachineEventDataItemSetImpl();
        for ( EventParameterReference eventparameterreference : this ) statemachineeventdataitemset.add( eventparameterreference.R846_StateMachineEventDataItem() );
        return statemachineeventdataitemset;
    }
    @Override
    public PropertyParameterSet R847_PropertyParameter() throws XtumlException {
        PropertyParameterSet propertyparameterset = new PropertyParameterSetImpl();
        for ( EventParameterReference eventparameterreference : this ) propertyparameterset.add( eventparameterreference.R847_PropertyParameter() );
        return propertyparameterset;
    }


    @Override
    public EventParameterReference nullElement() {
        return EventParameterReferenceImpl.EMPTY_EVENTPARAMETERREFERENCE;
    }

    @Override
    public EventParameterReferenceSet emptySet() {
      return new EventParameterReferenceSetImpl();
    }

    @Override
    public EventParameterReferenceSet emptySet(Comparator<? super EventParameterReference> comp) {
      return new EventParameterReferenceSetImpl(comp);
    }

    @Override
    public EventParameterReferenceSet value() {
        return this;
    }

    @Override
    public List<EventParameterReference> elements() {
        return Arrays.asList(toArray(new EventParameterReference[0]));
    }

}
